==> lbt-grasshopper-1.0.0.tar.gz: lbt-grasshopper-1.0.0/README.md <==
[![Build Status](https://travis-ci.org/ladybug-tools/lbt-grasshopper.svg?branch=master)](https://travis-ci.org/ladybug-tools/lbt-grasshopper)

[![IronPython](https://img.shields.io/badge/ironpython-2.7-red.svg)](https://github.com/IronLanguages/ironpython2/releases/tag/ipy-2.7.8/)

# lbt-grasshopper

Collection of all Ladybug Tools plugins for Grasshopper.

Note that this repository and corresponding Python package does not contain any
code and it simply exists to provide a shortcut for installing all of the grasshopper
plugin packages together. The repository CI also manages the assignment of version
numbers to the totality of the grasshopper plugins together.

## Included Grasshopper Plugins

Running `pip install lbt-grasshopper` will result in the installation of the
following Grasshopper plugin packages:

* [ladybug-grasshopper](https://github.com/ladybug-tools/ladybug-grasshopper)
* [honeybee-grasshopper-core](https://github.com/ladybug-tools/honeybee-grasshopper-core)
* [honeybee-grasshopper-radiance](https://github.com/ladybug-tools/honeybee-grasshopper-radiance)
* [honeybee-grasshopper-radiance](https://github.com/ladybug-tools/honeybee-grasshopper-energy)
* [dragonfly-grasshopper](https://github.com/ladybug-tools/dragonfly-grasshopper)

## Installation

See [the wiki of this repository](https://github.com/ladybug-tools/lbt-grasshopper/wiki)
for a list of instructions to install the Grasshopper plugin for free.

Ladybug Tools also offers purchase-able single-click executable installers,
which make it much faster and easier to install, particularly in the case of
deploying to multiple machines. If you are interested in purchasing the installer,
please email info@ladybug.tools

==> lbt-grasshopper-1.0.27.tar.gz: lbt-grasshopper-1.0.27/README.md <==
[![Build Status](https://travis-ci.org/ladybug-tools/lbt-grasshopper.svg?branch=master)](https://travis-ci.org/ladybug-tools/lbt-grasshopper)

[![IronPython](https://img.shields.io/badge/ironpython-2.7-red.svg)](https://github.com/IronLanguages/ironpython2/releases/tag/ipy-2.7.8/)

# lbt-grasshopper

Collection of all Ladybug Tools plugins for Grasshopper.

Note that this repository and corresponding Python package does not contain any
code and it simply exists to provide a shortcut for installing all of the grasshopper
plugin packages together. The repository CI also manages the assignment of version
numbers to the totality of the grasshopper plugins together.

## Included Grasshopper Plugins

Running `pip install lbt-grasshopper` will result in the installation of the
following Grasshopper plugin packages:

* [ladybug-grasshopper](https://github.com/ladybug-tools/ladybug-grasshopper)
* [honeybee-grasshopper-core](https://github.com/ladybug-tools/honeybee-grasshopper-core)
* [honeybee-grasshopper-radiance](https://github.com/ladybug-tools/honeybee-grasshopper-radiance)
* [honeybee-grasshopper-energy](https://github.com/ladybug-tools/honeybee-grasshopper-energy)
* [dragonfly-grasshopper](https://github.com/ladybug-tools/dragonfly-grasshopper)

## Installation

See [the wiki of this repository](https://github.com/ladybug-tools/lbt-grasshopper/wiki)
for a list of instructions to install the Grasshopper plugin for free.

Ladybug Tools also offers purchase-able single-click executable installers,
which make it much faster and easier to install, particularly in the case of
deploying to multiple machines. If you are interested in purchasing the installer,
please email info@ladybug.tools
